@@ -145,7 +145,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0860, 0x086a},
 {0x0870, 0x088e},
 {0x0890, 0x0891},
-{0x0898, 0x0983},
+{0x0897, 0x0983},
 {0x0985, 0x098c},
 {0x098f, 0x0990},
 {0x0993, 0x09a8},
@@ -339,11 +339,10 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1aa0, 0x1aad},
 {0x1ab0, 0x1ace},
 {0x1b00, 0x1b4c},
-{0x1b50, 0x1b7e},
-{0x1b80, 0x1bf3},
+{0x1b4e, 0x1bf3},
 {0x1bfc, 0x1c37},
 {0x1c3b, 0x1c49},
-{0x1c4d, 0x1c88},
+{0x1c4d, 0x1c8a},
 {0x1c90, 0x1cba},
 {0x1cbd, 0x1cc7},
 {0x1cd0, 0x1cfa},
@@ -504,7 +503,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x23f0, 0x23f0},
 {0x23f1, 0x23f2},
 {0x23f3, 0x23f3},
-{0x23f4, 0x2426},
+{0x23f4, 0x2429},
 {0x2440, 0x244a},
 {0x2460, 0x24e9},
 {0x24ea, 0x24ea},
@@ -551,7 +550,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x261c, 0x261c},
 {0x261d, 0x261d},
 {0x261e, 0x261e},
-{0x261f, 0x263f},
+{0x261f, 0x262f},
+{0x2630, 0x2637},
+{0x2638, 0x263f},
 {0x2640, 0x2640},
 {0x2641, 0x2641},
 {0x2642, 0x2642},
@@ -569,7 +570,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x266f, 0x266f},
 {0x2670, 0x267e},
 {0x267f, 0x267f},
-{0x2680, 0x2692},
+{0x2680, 0x2689},
+{0x268a, 0x268f},
+{0x2690, 0x2692},
 {0x2693, 0x2693},
 {0x2694, 0x269d},
 {0x269e, 0x269f},
@@ -665,20 +668,18 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x3099, 0x30ff},
 {0x3105, 0x312f},
 {0x3131, 0x318e},
-{0x3190, 0x31e3},
+{0x3190, 0x31e5},
 {0x31ef, 0x321e},
 {0x3220, 0x3247},
 {0x3248, 0x324f},
-{0x3250, 0x4dbf},
-{0x4dc0, 0x4dff},
-{0x4e00, 0xa48c},
+{0x3250, 0xa48c},
 {0xa490, 0xa4c6},
 {0xa4d0, 0xa62b},
 {0xa640, 0xa6f7},
-{0xa700, 0xa7ca},
+{0xa700, 0xa7cd},
 {0xa7d0, 0xa7d1},
 {0xa7d3, 0xa7d3},
-{0xa7d5, 0xa7d9},
+{0xa7d5, 0xa7dc},
 {0xa7f2, 0xa82c},
 {0xa830, 0xa839},
 {0xa840, 0xa877},
@@ -776,6 +777,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x105a3, 0x105b1},
 {0x105b3, 0x105b9},
 {0x105bb, 0x105bc},
+{0x105c0, 0x105f3},
 {0x10600, 0x10736},
 {0x10740, 0x10755},
 {0x10760, 0x10767},
@@ -819,11 +821,15 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x10cc0, 0x10cf2},
 {0x10cfa, 0x10d27},
 {0x10d30, 0x10d39},
+{0x10d40, 0x10d65},
+{0x10d69, 0x10d85},
+{0x10d8e, 0x10d8f},
 {0x10e60, 0x10e7e},
 {0x10e80, 0x10ea9},
 {0x10eab, 0x10ead},
 {0x10eb0, 0x10eb1},
-{0x10efd, 0x10f27},
+{0x10ec2, 0x10ec4},
+{0x10efc, 0x10f27},
 {0x10f30, 0x10f59},
 {0x10f70, 0x10f89},
 {0x10fb0, 0x10fcb},
@@ -863,6 +869,17 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1135d, 0x11363},
 {0x11366, 0x1136c},
 {0x11370, 0x11374},
+{0x11380, 0x11389},
+{0x1138b, 0x1138b},
+{0x1138e, 0x1138e},
+{0x11390, 0x113b5},
+{0x113b7, 0x113c0},
+{0x113c2, 0x113c2},
+{0x113c5, 0x113c5},
+{0x113c7, 0x113ca},
+{0x113cc, 0x113d5},
+{0x113d7, 0x113d8},
+{0x113e1, 0x113e2},
 {0x11400, 0x1145b},
 {0x1145d, 0x11461},
 {0x11480, 0x114c7},
@@ -874,6 +891,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11660, 0x1166c},
 {0x11680, 0x116b9},
 {0x116c0, 0x116c9},
+{0x116d0, 0x116e3},
 {0x11700, 0x1171a},
 {0x1171d, 0x1172b},
 {0x11730, 0x11746},
@@ -894,6 +912,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11a50, 0x11aa2},
 {0x11ab0, 0x11af8},
 {0x11b00, 0x11b09},
+{0x11bc0, 0x11be1},
+{0x11bf0, 0x11bf9},
 {0x11c00, 0x11c08},
 {0x11c0a, 0x11c36},
 {0x11c38, 0x11c45},
@@ -917,7 +937,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11ee0, 0x11ef8},
 {0x11f00, 0x11f10},
 {0x11f12, 0x11f3a},
-{0x11f3e, 0x11f59},
+{0x11f3e, 0x11f5a},
 {0x11fb0, 0x11fb0},
 {0x11fc0, 0x11ff1},
 {0x11fff, 0x12399},
@@ -926,7 +946,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x12480, 0x12543},
 {0x12f90, 0x12ff2},
 {0x13000, 0x13455},
+{0x13460, 0x143fa},
 {0x14400, 0x14646},
+{0x16100, 0x16139},
 {0x16800, 0x16a38},
 {0x16a40, 0x16a5e},
 {0x16a60, 0x16a69},
@@ -939,6 +961,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x16b5b, 0x16b61},
 {0x16b63, 0x16b77},
 {0x16b7d, 0x16b8f},
+{0x16d40, 0x16d79},
 {0x16e40, 0x16e9a},
 {0x16f00, 0x16f4a},
 {0x16f4f, 0x16f87},
@@ -947,7 +970,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x16ff0, 0x16ff1},
 {0x17000, 0x187f7},
 {0x18800, 0x18cd5},
-{0x18d00, 0x18d08},
+{0x18cff, 0x18d08},
 {0x1aff0, 0x1aff3},
 {0x1aff5, 0x1affb},
 {0x1affd, 0x1affe},
@@ -962,6 +985,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1bc80, 0x1bc88},
 {0x1bc90, 0x1bc99},
 {0x1bc9c, 0x1bca3},
+{0x1cc00, 0x1ccf9},
+{0x1cd00, 0x1ceb3},
 {0x1cf00, 0x1cf2d},
 {0x1cf30, 0x1cf46},
 {0x1cf50, 0x1cfc3},
@@ -972,7 +997,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1d2c0, 0x1d2d3},
 {0x1d2e0, 0x1d2f3},
 {0x1d300, 0x1d356},
-{0x1d360, 0x1d378},
+{0x1d360, 0x1d376},
+{0x1d377, 0x1d378},
 {0x1d400, 0x1d454},
 {0x1d456, 0x1d49c},
 {0x1d49e, 0x1d49f},
@@ -1013,6 +1039,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1e2c0, 0x1e2f9},
 {0x1e2ff, 0x1e2ff},
 {0x1e4d0, 0x1e4f9},
+{0x1e5d0, 0x1e5fa},
+{0x1e5ff, 0x1e5ff},
 {0x1e7e0, 0x1e7e6},
 {0x1e7e8, 0x1e7eb},
 {0x1e7ed, 0x1e7ee},
@@ -1142,7 +1170,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1f850, 0x1f859},
 {0x1f860, 0x1f887},
 {0x1f890, 0x1f8ad},
-{0x1f8b0, 0x1f8b1},
+{0x1f8b0, 0x1f8bb},
+{0x1f8c0, 0x1f8c1},
 {0x1f900, 0x1f90b},
 {0x1f90c, 0x1f93a},
 {0x1f93b, 0x1f93b},
@@ -1152,15 +1181,13 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1fa00, 0x1fa53},
 {0x1fa60, 0x1fa6d},
 {0x1fa70, 0x1fa7c},
-{0x1fa80, 0x1fa88},
-{0x1fa90, 0x1fabd},
-{0x1fabf, 0x1fac5},
-{0x1face, 0x1fadb},
-{0x1fae0, 0x1fae8},
+{0x1fa80, 0x1fa89},
+{0x1fa8f, 0x1fac6},
+{0x1face, 0x1fadc},
+{0x1fadf, 0x1fae9},
 {0x1faf0, 0x1faf8},
 {0x1fb00, 0x1fb92},
-{0x1fb94, 0x1fbca},
-{0x1fbf0, 0x1fbf9},
+{0x1fb94, 0x1fbf9},
 {0x20000, 0x2fffd},
 {0x30000, 0x3fffd},
 {0xe0001, 0xe0001},
@@ -1535,7 +1562,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
@@ -1724,6 +1750,8 @@ UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
@@ -1744,6 +1772,8 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
@@ -1842,8 +1872,6 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2115,6 +2143,28 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
@@ -2145,6 +2195,11 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2316,6 +2371,7 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
@@ -2329,8 +2385,6 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
