@@ -35,7 +35,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0829 & 0xFF, 0x082d & 0xFF},
 	{0x0859 & 0xFF, 0x085b & 0xFF},
 	{0x0890 & 0xFF, 0x0891 & 0xFF},
-	{0x0898 & 0xFF, 0x089f & 0xFF},
+	{0x0897 & 0xFF, 0x089f & 0xFF},
 	{0x08ca & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
@@ -118,14 +118,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c82 & 0xFF, 0x0c83 & 0xFF},
 	{0x0cbc & 0xFF, 0x0cbc & 0xFF},
 	{0x0cbe & 0xFF, 0x0cbe & 0xFF},
-	{0x0cbf & 0xFF, 0x0cbf & 0xFF},
-	{0x0cc0 & 0xFF, 0x0cc1 & 0xFF},
+	{0x0cbf & 0xFF, 0x0cc0 & 0xFF},
+	{0x0cc1 & 0xFF, 0x0cc1 & 0xFF},
 	{0x0cc2 & 0xFF, 0x0cc2 & 0xFF},
 	{0x0cc3 & 0xFF, 0x0cc4 & 0xFF},
-	{0x0cc6 & 0xFF, 0x0cc6 & 0xFF},
-	{0x0cc7 & 0xFF, 0x0cc8 & 0xFF},
-	{0x0cca & 0xFF, 0x0ccb & 0xFF},
-	{0x0ccc & 0xFF, 0x0ccd & 0xFF},
+	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
+	{0x0cca & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
 	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
 	{0x0cf3 & 0xFF, 0x0cf3 & 0xFF},
@@ -190,10 +188,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1160 & 0xFF, 0x11a7 & 0xFF},
 	{0x11a8 & 0xFF, 0x11ff & 0xFF},
 	{0x135d & 0xFF, 0x135f & 0xFF},
-	{0x1712 & 0xFF, 0x1714 & 0xFF},
-	{0x1715 & 0xFF, 0x1715 & 0xFF},
-	{0x1732 & 0xFF, 0x1733 & 0xFF},
-	{0x1734 & 0xFF, 0x1734 & 0xFF},
+	{0x1712 & 0xFF, 0x1715 & 0xFF},
+	{0x1732 & 0xFF, 0x1734 & 0xFF},
 	{0x1752 & 0xFF, 0x1753 & 0xFF},
 	{0x1772 & 0xFF, 0x1773 & 0xFF},
 	{0x17b4 & 0xFF, 0x17b5 & 0xFF},
@@ -233,29 +229,23 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
 	{0x1b00 & 0xFF, 0x1b03 & 0xFF},
 	{0x1b04 & 0xFF, 0x1b04 & 0xFF},
-	{0x1b34 & 0xFF, 0x1b3a & 0xFF},
-	{0x1b3b & 0xFF, 0x1b3b & 0xFF},
-	{0x1b3c & 0xFF, 0x1b3c & 0xFF},
-	{0x1b3d & 0xFF, 0x1b41 & 0xFF},
-	{0x1b42 & 0xFF, 0x1b42 & 0xFF},
-	{0x1b43 & 0xFF, 0x1b44 & 0xFF},
+	{0x1b34 & 0xFF, 0x1b3d & 0xFF},
+	{0x1b3e & 0xFF, 0x1b41 & 0xFF},
+	{0x1b42 & 0xFF, 0x1b44 & 0xFF},
 	{0x1b6b & 0xFF, 0x1b73 & 0xFF},
 	{0x1b80 & 0xFF, 0x1b81 & 0xFF},
 	{0x1b82 & 0xFF, 0x1b82 & 0xFF},
 	{0x1ba1 & 0xFF, 0x1ba1 & 0xFF},
 	{0x1ba2 & 0xFF, 0x1ba5 & 0xFF},
 	{0x1ba6 & 0xFF, 0x1ba7 & 0xFF},
-	{0x1ba8 & 0xFF, 0x1ba9 & 0xFF},
-	{0x1baa & 0xFF, 0x1baa & 0xFF},
-	{0x1bab & 0xFF, 0x1bad & 0xFF},
+	{0x1ba8 & 0xFF, 0x1bad & 0xFF},
 	{0x1be6 & 0xFF, 0x1be6 & 0xFF},
 	{0x1be7 & 0xFF, 0x1be7 & 0xFF},
 	{0x1be8 & 0xFF, 0x1be9 & 0xFF},
 	{0x1bea & 0xFF, 0x1bec & 0xFF},
 	{0x1bed & 0xFF, 0x1bed & 0xFF},
 	{0x1bee & 0xFF, 0x1bee & 0xFF},
-	{0x1bef & 0xFF, 0x1bf1 & 0xFF},
-	{0x1bf2 & 0xFF, 0x1bf3 & 0xFF},
+	{0x1bef & 0xFF, 0x1bf3 & 0xFF},
 	{0x1c24 & 0xFF, 0x1c2b & 0xFF},
 	{0x1c2c & 0xFF, 0x1c33 & 0xFF},
 	{0x1c34 & 0xFF, 0x1c35 & 0xFF},
@@ -299,7 +289,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa8ff & 0xFF, 0xa8ff & 0xFF},
 	{0xa926 & 0xFF, 0xa92d & 0xFF},
 	{0xa947 & 0xFF, 0xa951 & 0xFF},
-	{0xa952 & 0xFF, 0xa953 & 0xFF},
+	{0xa952 & 0xFF, 0xa952 & 0xFF},
+	{0xa953 & 0xFF, 0xa953 & 0xFF},
 	{0xa960 & 0xFF, 0xa97c & 0xFF},
 	{0xa980 & 0xFF, 0xa982 & 0xFF},
 	{0xa983 & 0xFF, 0xa983 & 0xFF},
@@ -308,7 +299,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa9b6 & 0xFF, 0xa9b9 & 0xFF},
 	{0xa9ba & 0xFF, 0xa9bb & 0xFF},
 	{0xa9bc & 0xFF, 0xa9bd & 0xFF},
-	{0xa9be & 0xFF, 0xa9c0 & 0xFF},
+	{0xa9be & 0xFF, 0xa9bf & 0xFF},
+	{0xa9c0 & 0xFF, 0xa9c0 & 0xFF},
 	{0xa9e5 & 0xFF, 0xa9e5 & 0xFF},
 	{0xaa29 & 0xFF, 0xaa2e & 0xFF},
 	{0xaa2f & 0xFF, 0xaa30 & 0xFF},
@@ -1189,8 +1181,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10a3f & 0xFF, 0x10a3f & 0xFF},
 	{0x10ae5 & 0xFF, 0x10ae6 & 0xFF},
 	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
+	{0x10d69 & 0xFF, 0x10d6d & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
-	{0x10efd & 0xFF, 0x10eff & 0xFF},
+	{0x10efc & 0xFF, 0x10eff & 0xFF},
 	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
 	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
 	{0x11000 & 0xFF, 0x11000 & 0xFF},
@@ -1218,7 +1211,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11182 & 0xFF, 0x11182 & 0xFF},
 	{0x111b3 & 0xFF, 0x111b5 & 0xFF},
 	{0x111b6 & 0xFF, 0x111be & 0xFF},
-	{0x111bf & 0xFF, 0x111c0 & 0xFF},
+	{0x111bf & 0xFF, 0x111bf & 0xFF},
+	{0x111c0 & 0xFF, 0x111c0 & 0xFF},
 	{0x111c2 & 0xFF, 0x111c3 & 0xFF},
 	{0x111c9 & 0xFF, 0x111cc & 0xFF},
 	{0x111ce & 0xFF, 0x111ce & 0xFF},
@@ -1226,9 +1220,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1122c & 0xFF, 0x1122e & 0xFF},
 	{0x1122f & 0xFF, 0x11231 & 0xFF},
 	{0x11232 & 0xFF, 0x11233 & 0xFF},
-	{0x11234 & 0xFF, 0x11234 & 0xFF},
-	{0x11235 & 0xFF, 0x11235 & 0xFF},
-	{0x11236 & 0xFF, 0x11237 & 0xFF},
+	{0x11234 & 0xFF, 0x11237 & 0xFF},
 	{0x1123e & 0xFF, 0x1123e & 0xFF},
 	{0x11241 & 0xFF, 0x11241 & 0xFF},
 	{0x112df & 0xFF, 0x112df & 0xFF},
@@ -1242,11 +1234,24 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11340 & 0xFF, 0x11340 & 0xFF},
 	{0x11341 & 0xFF, 0x11344 & 0xFF},
 	{0x11347 & 0xFF, 0x11348 & 0xFF},
-	{0x1134b & 0xFF, 0x1134d & 0xFF},
+	{0x1134b & 0xFF, 0x1134c & 0xFF},
+	{0x1134d & 0xFF, 0x1134d & 0xFF},
 	{0x11357 & 0xFF, 0x11357 & 0xFF},
 	{0x11362 & 0xFF, 0x11363 & 0xFF},
 	{0x11366 & 0xFF, 0x1136c & 0xFF},
 	{0x11370 & 0xFF, 0x11374 & 0xFF},
+	{0x113b8 & 0xFF, 0x113b8 & 0xFF},
+	{0x113b9 & 0xFF, 0x113ba & 0xFF},
+	{0x113bb & 0xFF, 0x113c0 & 0xFF},
+	{0x113c2 & 0xFF, 0x113c2 & 0xFF},
+	{0x113c5 & 0xFF, 0x113c5 & 0xFF},
+	{0x113c7 & 0xFF, 0x113c9 & 0xFF},
+	{0x113ca & 0xFF, 0x113ca & 0xFF},
+	{0x113cc & 0xFF, 0x113cd & 0xFF},
+	{0x113ce & 0xFF, 0x113d0 & 0xFF},
+	{0x113d1 & 0xFF, 0x113d1 & 0xFF},
+	{0x113d2 & 0xFF, 0x113d2 & 0xFF},
+	{0x113e1 & 0xFF, 0x113e2 & 0xFF},
 	{0x11435 & 0xFF, 0x11437 & 0xFF},
 	{0x11438 & 0xFF, 0x1143f & 0xFF},
 	{0x11440 & 0xFF, 0x11441 & 0xFF},
@@ -1283,10 +1288,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x116ac & 0xFF, 0x116ac & 0xFF},
 	{0x116ad & 0xFF, 0x116ad & 0xFF},
 	{0x116ae & 0xFF, 0x116af & 0xFF},
-	{0x116b0 & 0xFF, 0x116b5 & 0xFF},
-	{0x116b6 & 0xFF, 0x116b6 & 0xFF},
-	{0x116b7 & 0xFF, 0x116b7 & 0xFF},
-	{0x1171d & 0xFF, 0x1171f & 0xFF},
+	{0x116b0 & 0xFF, 0x116b7 & 0xFF},
+	{0x1171d & 0xFF, 0x1171d & 0xFF},
+	{0x1171e & 0xFF, 0x1171e & 0xFF},
+	{0x1171f & 0xFF, 0x1171f & 0xFF},
 	{0x11722 & 0xFF, 0x11725 & 0xFF},
 	{0x11726 & 0xFF, 0x11726 & 0xFF},
 	{0x11727 & 0xFF, 0x1172b & 0xFF},
@@ -1297,9 +1302,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11930 & 0xFF, 0x11930 & 0xFF},
 	{0x11931 & 0xFF, 0x11935 & 0xFF},
 	{0x11937 & 0xFF, 0x11938 & 0xFF},
-	{0x1193b & 0xFF, 0x1193c & 0xFF},
-	{0x1193d & 0xFF, 0x1193d & 0xFF},
-	{0x1193e & 0xFF, 0x1193e & 0xFF},
+	{0x1193b & 0xFF, 0x1193e & 0xFF},
 	{0x1193f & 0xFF, 0x1193f & 0xFF},
 	{0x11940 & 0xFF, 0x11940 & 0xFF},
 	{0x11941 & 0xFF, 0x11941 & 0xFF},
@@ -1356,14 +1359,18 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11f34 & 0xFF, 0x11f35 & 0xFF},
 	{0x11f36 & 0xFF, 0x11f3a & 0xFF},
 	{0x11f3e & 0xFF, 0x11f3f & 0xFF},
-	{0x11f40 & 0xFF, 0x11f40 & 0xFF},
-	{0x11f41 & 0xFF, 0x11f41 & 0xFF},
-	{0x11f42 & 0xFF, 0x11f42 & 0xFF},
+	{0x11f40 & 0xFF, 0x11f42 & 0xFF},
+	{0x11f5a & 0xFF, 0x11f5a & 0xFF},
 	{0x13430 & 0xFF, 0x1343f & 0xFF},
 	{0x13440 & 0xFF, 0x13440 & 0xFF},
 	{0x13447 & 0xFF, 0x13455 & 0xFF},
+	{0x1611e & 0xFF, 0x16129 & 0xFF},
+	{0x1612a & 0xFF, 0x1612c & 0xFF},
+	{0x1612d & 0xFF, 0x1612f & 0xFF},
 	{0x16af0 & 0xFF, 0x16af4 & 0xFF},
 	{0x16b30 & 0xFF, 0x16b36 & 0xFF},
+	{0x16d63 & 0xFF, 0x16d63 & 0xFF},
+	{0x16d67 & 0xFF, 0x16d6a & 0xFF},
 	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
 	{0x16f51 & 0xFF, 0x16f87 & 0xFF},
 	{0x16f8f & 0xFF, 0x16f92 & 0xFF},
@@ -1373,11 +1380,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
 	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
 	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
-	{0x1d165 & 0xFF, 0x1d165 & 0xFF},
-	{0x1d166 & 0xFF, 0x1d166 & 0xFF},
-	{0x1d167 & 0xFF, 0x1d169 & 0xFF},
-	{0x1d16d & 0xFF, 0x1d16d & 0xFF},
-	{0x1d16e & 0xFF, 0x1d172 & 0xFF},
+	{0x1d165 & 0xFF, 0x1d169 & 0xFF},
+	{0x1d16d & 0xFF, 0x1d172 & 0xFF},
 	{0x1d173 & 0xFF, 0x1d17a & 0xFF},
 	{0x1d17b & 0xFF, 0x1d182 & 0xFF},
 	{0x1d185 & 0xFF, 0x1d18b & 0xFF},
@@ -1399,6 +1403,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e2ae & 0xFF, 0x1e2ae & 0xFF},
 	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
 	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
+	{0x1e5ee & 0xFF, 0x1e5ef & 0xFF},
 	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
 	{0x1e944 & 0xFF, 0x1e94a & 0xFF},
 	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
@@ -1548,8 +1553,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1616,9 +1619,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_T,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1661,9 +1662,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -1671,8 +1669,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1681,7 +1677,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1725,6 +1720,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_L,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -1736,6 +1732,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2618,6 +2615,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2644,6 +2642,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Prepend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2652,8 +2651,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2669,9 +2666,22 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Prepend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2709,8 +2719,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2723,8 +2733,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Prepend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Prepend,
@@ -2782,18 +2790,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Control,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2801,13 +2797,27 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_V,
+	UNICODE_GRAPHEMEBREAK_V,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Control,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2952,8 +2962,10 @@ static const size_t unicode_starting_indextab[]={
 	286,
 	287,
 	308,
+	353,
 	362,
 	363,
+	365,
 	367,
 	444,
 	463,
@@ -2964,6 +2976,7 @@ static const size_t unicode_starting_indextab[]={
 	481,
 	482,
 	484,
+	485,
 	488,
 	489,
 	497,
@@ -2998,121 +3011,119 @@ static const char32_t unicode_starting_pagetab[]={
 	64,
 	85,
 	105,
-	130,
-	152,
-	160,
-	172,
-	187,
-	190,
-	191,
-	205,
-	210,
-	218,
-	232,
-	257,
-	269,
+	128,
+	150,
+	158,
+	170,
+	185,
+	188,
+	189,
+	201,
+	206,
+	214,
+	228,
+	247,
+	259,
+	260,
+	267,
+	268,
 	270,
-	277,
-	278,
-	280,
-	282,
-	286,
-	298,
-	311,
-	330,
-	337,
-	357,
-	376,
-	395,
-	414,
-	433,
-	452,
-	471,
-	491,
-	510,
-	529,
-	548,
-	567,
-	586,
-	605,
-	625,
-	644,
-	663,
-	682,
-	701,
-	720,
-	739,
-	759,
-	778,
-	797,
-	816,
-	835,
-	854,
-	873,
-	893,
-	912,
-	931,
-	950,
-	969,
-	988,
-	1007,
-	1027,
-	1046,
-	1065,
-	1084,
-	1103,
-	1122,
-	1141,
-	1161,
+	272,
+	276,
+	288,
+	303,
+	322,
+	329,
+	349,
+	368,
+	387,
+	406,
+	425,
+	444,
+	463,
+	483,
+	502,
+	521,
+	540,
+	559,
+	578,
+	597,
+	617,
+	636,
+	655,
+	674,
+	693,
+	712,
+	731,
+	751,
+	770,
+	789,
+	808,
+	827,
+	846,
+	865,
+	885,
+	904,
+	923,
+	942,
+	961,
+	980,
+	999,
+	1019,
+	1038,
+	1057,
+	1076,
+	1095,
+	1114,
+	1133,
+	1153,
+	1166,
+	1167,
+	1170,
+	1172,
+	1173,
 	1174,
 	1175,
-	1178,
-	1180,
 	1181,
-	1182,
 	1183,
-	1189,
-	1190,
-	1192,
-	1194,
-	1209,
-	1224,
-	1235,
-	1248,
-	1266,
-	1274,
-	1287,
-	1291,
-	1295,
-	1312,
-	1325,
-	1337,
-	1349,
-	1351,
-	1360,
-	1363,
-	1364,
+	1185,
+	1187,
+	1202,
+	1218,
+	1227,
+	1253,
+	1271,
+	1279,
+	1290,
+	1296,
+	1300,
+	1315,
+	1328,
+	1340,
+	1352,
+	1354,
+	1362,
 	1365,
+	1368,
+	1369,
 	1370,
 	1372,
-	1374,
-	1383,
-	1384,
-	1390,
-	1396,
-	1397,
-	1399,
+	1377,
+	1379,
+	1381,
+	1387,
+	1388,
+	1394,
 	1400,
 	1401,
-	1402,
 	1403,
 	1404,
+	1405,
+	1406,
 	1407,
+	1408,
 	1409,
-	1410,
-	1411,
 	1412,
-	1413,
 	1414,
 	1415,
 	1416,
@@ -3121,6 +3132,11 @@ static const char32_t unicode_starting_pagetab[]={
 	1419,
 	1420,
 	1421,
-	1422
+	1422,
+	1423,
+	1424,
+	1425,
+	1426,
+	1427
 };
 
