@@ -16,9 +16,17 @@ int main(int argc, char **argv)
 {
 	if (argc >= 3)
 	{
-		printf("%d\n",
-		       unicode_grapheme_break(strtol(argv[1], NULL, 0),
-					      strtol(argv[2], NULL, 0)));
+		unicode_grapheme_break_info_t t=unicode_grapheme_break_init();
+		int n=0;
+		int i;
+		for (i=1; i<argc; ++i)
+		{
+			n=unicode_grapheme_break_next(t,
+						      strtol(argv[i], NULL, 0));
+		}
+		unicode_grapheme_break_deinit(t);
+
+		printf("%d\n", n);
 	}
 	return (0);
 }
