@@ -78,7 +78,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0860 & 0xFF, 0x086a & 0xFF},
 	{0x0870 & 0xFF, 0x088e & 0xFF},
 	{0x0890 & 0xFF, 0x0891 & 0xFF},
-	{0x0898 & 0xFF, 0x08e1 & 0xFF},
+	{0x0897 & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
 	{0x0900 & 0xFF, 0x0950 & 0xFF},
@@ -303,7 +303,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1aa0 & 0xFF, 0x1aad & 0xFF},
 	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
 	{0x1b00 & 0xFF, 0x1b4c & 0xFF},
-	{0x1b50 & 0xFF, 0x1b7e & 0xFF},
+	{0x1b4e & 0xFF, 0x1b7f & 0xFF},
 	{0x1b80 & 0xFF, 0x1bbf & 0xFF},
 	{0x1bc0 & 0xFF, 0x1bf3 & 0xFF},
 	{0x1bfc & 0xFF, 0x1bff & 0xFF},
@@ -311,7 +311,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1c3b & 0xFF, 0x1c49 & 0xFF},
 	{0x1c4d & 0xFF, 0x1c4f & 0xFF},
 	{0x1c50 & 0xFF, 0x1c7f & 0xFF},
-	{0x1c80 & 0xFF, 0x1c88 & 0xFF},
+	{0x1c80 & 0xFF, 0x1c8a & 0xFF},
 	{0x1c90 & 0xFF, 0x1cba & 0xFF},
 	{0x1cbd & 0xFF, 0x1cbf & 0xFF},
 	{0x1cc0 & 0xFF, 0x1cc7 & 0xFF},
@@ -381,7 +381,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2190 & 0xFF, 0x21ff & 0xFF},
 	{0x2200 & 0xFF, 0x22ff & 0xFF},
 	{0x2300 & 0xFF, 0x23ff & 0xFF},
-	{0x2400 & 0xFF, 0x2426 & 0xFF},
+	{0x2400 & 0xFF, 0x2429 & 0xFF},
 	{0x2440 & 0xFF, 0x244a & 0xFF},
 	{0x2460 & 0xFF, 0x24ff & 0xFF},
 	{0x2500 & 0xFF, 0x25ff & 0xFF},
@@ -441,7 +441,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x3131 & 0xFF, 0x318e & 0xFF},
 	{0x3190 & 0xFF, 0x319f & 0xFF},
 	{0x31a0 & 0xFF, 0x31bf & 0xFF},
-	{0x31c0 & 0xFF, 0x31e3 & 0xFF},
+	{0x31c0 & 0xFF, 0x31e5 & 0xFF},
 	{0x31ef & 0xFF, 0x31ef & 0xFF},
 	{0x31f0 & 0xFF, 0x31ff & 0xFF},
 	{0x3200 & 0xFF, 0x321e & 0xFF},
@@ -575,10 +575,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa700 & 0xFF, 0xa721 & 0xFF},
 	{0xa722 & 0xFF, 0xa787 & 0xFF},
 	{0xa788 & 0xFF, 0xa78a & 0xFF},
-	{0xa78b & 0xFF, 0xa7ca & 0xFF},
+	{0xa78b & 0xFF, 0xa7cd & 0xFF},
 	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
 	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
-	{0xa7d5 & 0xFF, 0xa7d9 & 0xFF},
+	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
 	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa82c & 0xFF},
 	{0xa830 & 0xFF, 0xa839 & 0xFF},
@@ -756,6 +756,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
 	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
 	{0x105bb & 0xFF, 0x105bc & 0xFF},
+	{0x105c0 & 0xFF, 0x105f3 & 0xFF},
 	{0x10600 & 0xFF, 0x106ff & 0xFF},
 	{0x10700 & 0xFF, 0x10736 & 0xFF},
 	{0x10740 & 0xFF, 0x10755 & 0xFF},
@@ -812,11 +813,15 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10cfa & 0xFF, 0x10cff & 0xFF},
 	{0x10d00 & 0xFF, 0x10d27 & 0xFF},
 	{0x10d30 & 0xFF, 0x10d39 & 0xFF},
+	{0x10d40 & 0xFF, 0x10d65 & 0xFF},
+	{0x10d69 & 0xFF, 0x10d85 & 0xFF},
+	{0x10d8e & 0xFF, 0x10d8f & 0xFF},
 	{0x10e60 & 0xFF, 0x10e7e & 0xFF},
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10ead & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
-	{0x10efd & 0xFF, 0x10eff & 0xFF},
+	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
+	{0x10efc & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f59 & 0xFF},
 	{0x10f70 & 0xFF, 0x10f89 & 0xFF},
@@ -859,6 +864,17 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1135d & 0xFF, 0x11363 & 0xFF},
 	{0x11366 & 0xFF, 0x1136c & 0xFF},
 	{0x11370 & 0xFF, 0x11374 & 0xFF},
+	{0x11380 & 0xFF, 0x11389 & 0xFF},
+	{0x1138b & 0xFF, 0x1138b & 0xFF},
+	{0x1138e & 0xFF, 0x1138e & 0xFF},
+	{0x11390 & 0xFF, 0x113b5 & 0xFF},
+	{0x113b7 & 0xFF, 0x113c0 & 0xFF},
+	{0x113c2 & 0xFF, 0x113c2 & 0xFF},
+	{0x113c5 & 0xFF, 0x113c5 & 0xFF},
+	{0x113c7 & 0xFF, 0x113ca & 0xFF},
+	{0x113cc & 0xFF, 0x113d5 & 0xFF},
+	{0x113d7 & 0xFF, 0x113d8 & 0xFF},
+	{0x113e1 & 0xFF, 0x113e2 & 0xFF},
 	{0x11400 & 0xFF, 0x1145b & 0xFF},
 	{0x1145d & 0xFF, 0x11461 & 0xFF},
 	{0x11480 & 0xFF, 0x114c7 & 0xFF},
@@ -870,6 +886,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11660 & 0xFF, 0x1166c & 0xFF},
 	{0x11680 & 0xFF, 0x116b9 & 0xFF},
 	{0x116c0 & 0xFF, 0x116c9 & 0xFF},
+	{0x116d0 & 0xFF, 0x116e3 & 0xFF},
 	{0x11700 & 0xFF, 0x1171a & 0xFF},
 	{0x1171d & 0xFF, 0x1172b & 0xFF},
 	{0x11730 & 0xFF, 0x11746 & 0xFF},
@@ -892,6 +909,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11ab0 & 0xFF, 0x11abf & 0xFF},
 	{0x11ac0 & 0xFF, 0x11af8 & 0xFF},
 	{0x11b00 & 0xFF, 0x11b09 & 0xFF},
+	{0x11bc0 & 0xFF, 0x11be1 & 0xFF},
+	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
 	{0x11c0a & 0xFF, 0x11c36 & 0xFF},
 	{0x11c38 & 0xFF, 0x11c45 & 0xFF},
@@ -915,7 +934,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11ee0 & 0xFF, 0x11ef8 & 0xFF},
 	{0x11f00 & 0xFF, 0x11f10 & 0xFF},
 	{0x11f12 & 0xFF, 0x11f3a & 0xFF},
-	{0x11f3e & 0xFF, 0x11f59 & 0xFF},
+	{0x11f3e & 0xFF, 0x11f5a & 0xFF},
 	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
 	{0x11fc0 & 0xFF, 0x11ff1 & 0xFF},
 	{0x11fff & 0xFF, 0x11fff & 0xFF},
@@ -933,9 +952,26 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x13200 & 0xFF, 0x132ff & 0xFF},
 	{0x13300 & 0xFF, 0x133ff & 0xFF},
 	{0x13400 & 0xFF, 0x13455 & 0xFF},
+	{0x13460 & 0xFF, 0x134ff & 0xFF},
+	{0x13500 & 0xFF, 0x135ff & 0xFF},
+	{0x13600 & 0xFF, 0x136ff & 0xFF},
+	{0x13700 & 0xFF, 0x137ff & 0xFF},
+	{0x13800 & 0xFF, 0x138ff & 0xFF},
+	{0x13900 & 0xFF, 0x139ff & 0xFF},
+	{0x13a00 & 0xFF, 0x13aff & 0xFF},
+	{0x13b00 & 0xFF, 0x13bff & 0xFF},
+	{0x13c00 & 0xFF, 0x13cff & 0xFF},
+	{0x13d00 & 0xFF, 0x13dff & 0xFF},
+	{0x13e00 & 0xFF, 0x13eff & 0xFF},
+	{0x13f00 & 0xFF, 0x13fff & 0xFF},
+	{0x14000 & 0xFF, 0x140ff & 0xFF},
+	{0x14100 & 0xFF, 0x141ff & 0xFF},
+	{0x14200 & 0xFF, 0x142ff & 0xFF},
+	{0x14300 & 0xFF, 0x143fa & 0xFF},
 	{0x14400 & 0xFF, 0x144ff & 0xFF},
 	{0x14500 & 0xFF, 0x145ff & 0xFF},
 	{0x14600 & 0xFF, 0x14646 & 0xFF},
+	{0x16100 & 0xFF, 0x16139 & 0xFF},
 	{0x16800 & 0xFF, 0x168ff & 0xFF},
 	{0x16900 & 0xFF, 0x169ff & 0xFF},
 	{0x16a00 & 0xFF, 0x16a38 & 0xFF},
@@ -951,6 +987,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16b5b & 0xFF, 0x16b61 & 0xFF},
 	{0x16b63 & 0xFF, 0x16b77 & 0xFF},
 	{0x16b7d & 0xFF, 0x16b8f & 0xFF},
+	{0x16d40 & 0xFF, 0x16d79 & 0xFF},
 	{0x16e40 & 0xFF, 0x16e9a & 0xFF},
 	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
 	{0x16f4f & 0xFF, 0x16f87 & 0xFF},
@@ -989,6 +1026,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x18a00 & 0xFF, 0x18aff & 0xFF},
 	{0x18b00 & 0xFF, 0x18bff & 0xFF},
 	{0x18c00 & 0xFF, 0x18cd5 & 0xFF},
+	{0x18cff & 0xFF, 0x18cff & 0xFF},
 	{0x18d00 & 0xFF, 0x18d08 & 0xFF},
 	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
 	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
@@ -1009,6 +1047,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
 	{0x1bc9c & 0xFF, 0x1bc9f & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
+	{0x1cc00 & 0xFF, 0x1ccf9 & 0xFF},
+	{0x1cd00 & 0xFF, 0x1cdff & 0xFF},
+	{0x1ce00 & 0xFF, 0x1ceb3 & 0xFF},
 	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
 	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
 	{0x1cf50 & 0xFF, 0x1cfc3 & 0xFF},
@@ -1074,6 +1115,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e2c0 & 0xFF, 0x1e2f9 & 0xFF},
 	{0x1e2ff & 0xFF, 0x1e2ff & 0xFF},
 	{0x1e4d0 & 0xFF, 0x1e4f9 & 0xFF},
+	{0x1e5d0 & 0xFF, 0x1e5fa & 0xFF},
+	{0x1e5ff & 0xFF, 0x1e5ff & 0xFF},
 	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
 	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
 	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
@@ -1148,20 +1191,19 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1f850 & 0xFF, 0x1f859 & 0xFF},
 	{0x1f860 & 0xFF, 0x1f887 & 0xFF},
 	{0x1f890 & 0xFF, 0x1f8ad & 0xFF},
-	{0x1f8b0 & 0xFF, 0x1f8b1 & 0xFF},
+	{0x1f8b0 & 0xFF, 0x1f8bb & 0xFF},
+	{0x1f8c0 & 0xFF, 0x1f8c1 & 0xFF},
 	{0x1f900 & 0xFF, 0x1f9ff & 0xFF},
 	{0x1fa00 & 0xFF, 0x1fa53 & 0xFF},
 	{0x1fa60 & 0xFF, 0x1fa6d & 0xFF},
 	{0x1fa70 & 0xFF, 0x1fa7c & 0xFF},
-	{0x1fa80 & 0xFF, 0x1fa88 & 0xFF},
-	{0x1fa90 & 0xFF, 0x1fabd & 0xFF},
-	{0x1fabf & 0xFF, 0x1fac5 & 0xFF},
-	{0x1face & 0xFF, 0x1fadb & 0xFF},
-	{0x1fae0 & 0xFF, 0x1fae8 & 0xFF},
+	{0x1fa80 & 0xFF, 0x1fa89 & 0xFF},
+	{0x1fa8f & 0xFF, 0x1fac6 & 0xFF},
+	{0x1face & 0xFF, 0x1fadc & 0xFF},
+	{0x1fadf & 0xFF, 0x1fae9 & 0xFF},
 	{0x1faf0 & 0xFF, 0x1faf8 & 0xFF},
 	{0x1fb00 & 0xFF, 0x1fb92 & 0xFF},
-	{0x1fb94 & 0xFF, 0x1fbca & 0xFF},
-	{0x1fbf0 & 0xFF, 0x1fbf9 & 0xFF},
+	{0x1fb94 & 0xFF, 0x1fbf9 & 0xFF},
 	{0x20000 & 0xFF, 0x200ff & 0xFF},
 	{0x20100 & 0xFF, 0x201ff & 0xFF},
 	{0x20200 & 0xFF, 0x202ff & 0xFF},
@@ -2207,6 +2249,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_vithkuqi,
 	unicode_script_vithkuqi,
 	unicode_script_vithkuqi,
+	unicode_script_todhri,
 	unicode_script_linear_a,
 	unicode_script_linear_a,
 	unicode_script_linear_a,
@@ -2263,11 +2306,15 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_old_hungarian,
 	unicode_script_hanifi_rohingya,
 	unicode_script_hanifi_rohingya,
+	unicode_script_garay,
+	unicode_script_garay,
+	unicode_script_garay,
 	unicode_script_arabic,
 	unicode_script_yezidi,
 	unicode_script_yezidi,
 	unicode_script_yezidi,
 	unicode_script_arabic,
+	unicode_script_arabic,
 	unicode_script_old_sogdian,
 	unicode_script_sogdian,
 	unicode_script_old_uyghur,
@@ -2310,6 +2357,17 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_grantha,
 	unicode_script_grantha,
 	unicode_script_grantha,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
+	unicode_script_tulu_tigalari,
 	unicode_script_newa,
 	unicode_script_newa,
 	unicode_script_tirhuta,
@@ -2321,6 +2379,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_mongolian,
 	unicode_script_takri,
 	unicode_script_takri,
+	unicode_script_myanmar,
 	unicode_script_ahom,
 	unicode_script_ahom,
 	unicode_script_ahom,
@@ -2343,6 +2402,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_canadian_aboriginal,
 	unicode_script_pau_cin_hau,
 	unicode_script_devanagari,
+	unicode_script_sunuwar,
+	unicode_script_sunuwar,
 	unicode_script_bhaiksuki,
 	unicode_script_bhaiksuki,
 	unicode_script_bhaiksuki,
@@ -2384,9 +2445,26 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_egyptian_hieroglyphs,
 	unicode_script_egyptian_hieroglyphs,
 	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
+	unicode_script_egyptian_hieroglyphs,
 	unicode_script_anatolian_hieroglyphs,
 	unicode_script_anatolian_hieroglyphs,
 	unicode_script_anatolian_hieroglyphs,
+	unicode_script_gurung_khema,
 	unicode_script_bamum,
 	unicode_script_bamum,
 	unicode_script_bamum,
@@ -2402,6 +2480,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_pahawh_hmong,
 	unicode_script_pahawh_hmong,
 	unicode_script_pahawh_hmong,
+	unicode_script_kirat_rai,
 	unicode_script_medefaidrin,
 	unicode_script_miao,
 	unicode_script_miao,
@@ -2440,6 +2519,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_tangut,
 	unicode_script_khitan_small_script,
 	unicode_script_khitan_small_script,
+	unicode_script_khitan_small_script,
 	unicode_script_tangut,
 	unicode_script_katakana,
 	unicode_script_katakana,
@@ -2460,6 +2540,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_duployan,
 	unicode_script_duployan,
 	unicode_script_common,
+	unicode_script_common,
+	unicode_script_common,
+	unicode_script_common,
 	unicode_script_inherited,
 	unicode_script_inherited,
 	unicode_script_common,
@@ -2525,6 +2608,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_wancho,
 	unicode_script_wancho,
 	unicode_script_nag_mundari,
+	unicode_script_ol_onal,
+	unicode_script_ol_onal,
 	unicode_script_ethiopic,
 	unicode_script_ethiopic,
 	unicode_script_ethiopic,
@@ -2612,7 +2697,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
-	unicode_script_common,
 	unicode_script_han,
 	unicode_script_han,
 	unicode_script_han,
@@ -3168,13 +3252,30 @@ static const size_t unicode_starting_indextab[]={
 	306,
 	307,
 	308,
+	309,
+	310,
+	311,
+	312,
+	313,
+	314,
+	315,
+	316,
+	317,
+	318,
+	319,
+	320,
+	321,
+	322,
+	323,
 	324,
 	325,
 	326,
+	353,
 	360,
 	361,
 	362,
 	363,
+	365,
 	366,
 	367,
 	368,
@@ -3212,6 +3313,9 @@ static const size_t unicode_starting_indextab[]={
 	433,
 	434,
 	444,
+	460,
+	461,
+	462,
 	463,
 	464,
 	465,
@@ -3229,6 +3333,7 @@ static const size_t unicode_starting_indextab[]={
 	481,
 	482,
 	484,
+	485,
 	487,
 	488,
 	489,
@@ -3759,53 +3864,51 @@ static const char32_t unicode_starting_pagetab[]={
 	732,
 	740,
 	746,
-	757,
 	758,
-	764,
-	778,
-	786,
-	798,
-	807,
-	811,
-	813,
-	818,
+	759,
+	765,
+	779,
+	787,
+	799,
+	808,
+	812,
+	817,
 	823,
-	830,
+	828,
 	835,
-	844,
-	860,
-	864,
-	866,
-	871,
-	874,
-	877,
+	840,
+	849,
+	876,
+	880,
+	882,
 	888,
-	892,
-	893,
-	900,
-	913,
-	914,
-	920,
-	921,
-	922,
-	923,
-	924,
-	927,
-	928,
-	929,
-	930,
-	931,
+	891,
+	894,
+	905,
+	909,
+	912,
+	919,
 	932,
 	933,
-	934,
-	935,
-	936,
-	937,
-	938,
 	939,
+	940,
+	941,
+	942,
+	943,
+	946,
 	947,
+	948,
+	949,
+	950,
+	951,
 	952,
-	953,
+	954,
+	955,
+	956,
+	957,
+	958,
+	959,
+	960,
 	961,
 	962,
 	963,
@@ -3821,103 +3924,84 @@ static const char32_t unicode_starting_pagetab[]={
 	973,
 	974,
 	975,
-	976,
-	977,
-	978,
-	979,
-	980,
-	981,
-	982,
 	983,
-	984,
-	985,
-	986,
-	987,
 	988,
 	989,
 	990,
-	991,
-	994,
-	996,
+	998,
+	999,
+	1000,
+	1001,
+	1002,
 	1003,
 	1004,
+	1005,
+	1006,
+	1007,
+	1008,
+	1009,
 	1010,
+	1011,
+	1012,
 	1013,
 	1014,
+	1015,
+	1016,
+	1017,
+	1018,
+	1019,
+	1020,
+	1021,
+	1022,
+	1023,
 	1024,
-	1027,
+	1025,
+	1026,
+	1028,
 	1029,
-	1039,
+	1032,
+	1034,
+	1041,
+	1042,
+	1048,
 	1049,
+	1050,
 	1051,
-	1053,
 	1054,
 	1055,
-	1058,
-	1060,
-	1067,
-	1071,
-	1074,
-	1075,
-	1079,
-	1081,
-	1084,
-	1085,
-	1086,
-	1120,
-	1126,
+	1065,
+	1068,
+	1070,
+	1080,
+	1090,
+	1092,
+	1094,
+	1095,
+	1096,
+	1099,
+	1101,
+	1108,
+	1112,
+	1115,
+	1116,
+	1118,
+	1122,
+	1124,
+	1127,
 	1128,
-	1134,
-	1135,
-	1136,
-	1137,
-	1140,
-	1144,
-	1150,
-	1151,
-	1160,
+	1129,
 	1163,
-	1164,
-	1165,
-	1166,
-	1167,
-	1168,
 	1169,
-	1170,
 	1171,
-	1172,
-	1173,
-	1174,
-	1175,
-	1176,
 	1177,
 	1178,
 	1179,
 	1180,
-	1181,
-	1182,
 	1183,
-	1184,
-	1185,
-	1186,
 	1187,
-	1188,
-	1189,
-	1190,
-	1191,
-	1192,
-	1193,
 	1194,
 	1195,
-	1196,
-	1197,
-	1198,
-	1199,
-	1200,
-	1201,
-	1202,
 	1203,
-	1204,
 	1205,
 	1206,
 	1207,
@@ -4060,7 +4144,9 @@ static const char32_t unicode_starting_pagetab[]={
 	1344,
 	1345,
 	1346,
+	1347,
 	1348,
+	1349,
 	1350,
 	1351,
 	1352,
@@ -4083,6 +4169,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1369,
 	1370,
 	1371,
+	1372,
 	1373,
 	1374,
 	1375,
@@ -4099,9 +4186,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1386,
 	1387,
 	1388,
-	1389,
 	1390,
-	1391,
 	1392,
 	1393,
 	1394,
@@ -4112,6 +4197,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1399,
 	1400,
 	1401,
+	1402,
 	1403,
 	1404,
 	1405,
@@ -4123,7 +4209,6 @@ static const char32_t unicode_starting_pagetab[]={
 	1411,
 	1412,
 	1413,
-	1414,
 	1415,
 	1416,
 	1417,
@@ -4138,6 +4223,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1426,
 	1427,
 	1428,
+	1429,
 	1430,
 	1431,
 	1432,
@@ -4152,9 +4238,49 @@ static const char32_t unicode_starting_pagetab[]={
 	1441,
 	1442,
 	1443,
-	1444,
 	1445,
 	1446,
-	1448
+	1447,
+	1448,
+	1449,
+	1450,
+	1451,
+	1452,
+	1453,
+	1454,
+	1455,
+	1456,
+	1457,
+	1458,
+	1459,
+	1460,
+	1461,
+	1462,
+	1463,
+	1464,
+	1465,
+	1466,
+	1467,
+	1468,
+	1469,
+	1470,
+	1472,
+	1473,
+	1474,
+	1475,
+	1476,
+	1477,
+	1478,
+	1479,
+	1480,
+	1481,
+	1482,
+	1483,
+	1484,
+	1485,
+	1486,
+	1487,
+	1488,
+	1490
 };
 
