@@ -109,7 +109,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0870 & 0xFF, 0x0887 & 0xFF},
 	{0x0889 & 0xFF, 0x088e & 0xFF},
 	{0x0890 & 0xFF, 0x0891 & 0xFF},
-	{0x0898 & 0xFF, 0x089f & 0xFF},
+	{0x0897 & 0xFF, 0x089f & 0xFF},
 	{0x08a0 & 0xFF, 0x08c9 & 0xFF},
 	{0x08ca & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
@@ -377,7 +377,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1920 & 0xFF, 0x192b & 0xFF},
 	{0x1930 & 0xFF, 0x193b & 0xFF},
 	{0x1946 & 0xFF, 0x194f & 0xFF},
-	{0x19d0 & 0xFF, 0x19d9 & 0xFF},
+	{0x19d0 & 0xFF, 0x19da & 0xFF},
 	{0x1a00 & 0xFF, 0x1a16 & 0xFF},
 	{0x1a17 & 0xFF, 0x1a1b & 0xFF},
 	{0x1a55 & 0xFF, 0x1a5e & 0xFF},
@@ -405,7 +405,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1c4d & 0xFF, 0x1c4f & 0xFF},
 	{0x1c50 & 0xFF, 0x1c59 & 0xFF},
 	{0x1c5a & 0xFF, 0x1c7d & 0xFF},
-	{0x1c80 & 0xFF, 0x1c88 & 0xFF},
+	{0x1c80 & 0xFF, 0x1c8a & 0xFF},
 	{0x1c90 & 0xFF, 0x1cba & 0xFF},
 	{0x1cbd & 0xFF, 0x1cbf & 0xFF},
 	{0x1cd0 & 0xFF, 0x1cd2 & 0xFF},
@@ -529,10 +529,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa69e & 0xFF, 0xa69f & 0xFF},
 	{0xa6a0 & 0xFF, 0xa6ef & 0xFF},
 	{0xa6f0 & 0xFF, 0xa6f1 & 0xFF},
-	{0xa708 & 0xFF, 0xa7ca & 0xFF},
+	{0xa708 & 0xFF, 0xa7cd & 0xFF},
 	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
 	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
-	{0xa7d5 & 0xFF, 0xa7d9 & 0xFF},
+	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
 	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa801 & 0xFF},
 	{0xa802 & 0xFF, 0xa802 & 0xFF},
@@ -658,9 +658,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xfd92 & 0xFF, 0xfdc7 & 0xFF},
 	{0xfdf0 & 0xFF, 0xfdfb & 0xFF},
 	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
-	{0xfe10 & 0xFF, 0xfe10 & 0xFF},
 	{0xfe13 & 0xFF, 0xfe13 & 0xFF},
-	{0xfe14 & 0xFF, 0xfe14 & 0xFF},
 	{0xfe20 & 0xFF, 0xfe2f & 0xFF},
 	{0xfe33 & 0xFF, 0xfe34 & 0xFF},
 	{0xfe4d & 0xFF, 0xfe4f & 0xFF},
@@ -722,6 +720,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
 	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
 	{0x105bb & 0xFF, 0x105bc & 0xFF},
+	{0x105c0 & 0xFF, 0x105f3 & 0xFF},
 	{0x10600 & 0xFF, 0x106ff & 0xFF},
 	{0x10700 & 0xFF, 0x10736 & 0xFF},
 	{0x10740 & 0xFF, 0x10755 & 0xFF},
@@ -767,10 +766,15 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10d00 & 0xFF, 0x10d23 & 0xFF},
 	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
 	{0x10d30 & 0xFF, 0x10d39 & 0xFF},
+	{0x10d40 & 0xFF, 0x10d49 & 0xFF},
+	{0x10d4a & 0xFF, 0x10d65 & 0xFF},
+	{0x10d69 & 0xFF, 0x10d6d & 0xFF},
+	{0x10d6f & 0xFF, 0x10d85 & 0xFF},
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
-	{0x10efd & 0xFF, 0x10eff & 0xFF},
+	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
+	{0x10efc & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f1c & 0xFF},
 	{0x10f27 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f45 & 0xFF},
@@ -846,6 +850,20 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11362 & 0xFF, 0x11363 & 0xFF},
 	{0x11366 & 0xFF, 0x1136c & 0xFF},
 	{0x11370 & 0xFF, 0x11374 & 0xFF},
+	{0x11380 & 0xFF, 0x11389 & 0xFF},
+	{0x1138b & 0xFF, 0x1138b & 0xFF},
+	{0x1138e & 0xFF, 0x1138e & 0xFF},
+	{0x11390 & 0xFF, 0x113b5 & 0xFF},
+	{0x113b7 & 0xFF, 0x113b7 & 0xFF},
+	{0x113b8 & 0xFF, 0x113c0 & 0xFF},
+	{0x113c2 & 0xFF, 0x113c2 & 0xFF},
+	{0x113c5 & 0xFF, 0x113c5 & 0xFF},
+	{0x113c7 & 0xFF, 0x113ca & 0xFF},
+	{0x113cc & 0xFF, 0x113d0 & 0xFF},
+	{0x113d1 & 0xFF, 0x113d1 & 0xFF},
+	{0x113d2 & 0xFF, 0x113d2 & 0xFF},
+	{0x113d3 & 0xFF, 0x113d3 & 0xFF},
+	{0x113e1 & 0xFF, 0x113e2 & 0xFF},
 	{0x11400 & 0xFF, 0x11434 & 0xFF},
 	{0x11435 & 0xFF, 0x11446 & 0xFF},
 	{0x11447 & 0xFF, 0x1144a & 0xFF},
@@ -870,6 +888,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x116ab & 0xFF, 0x116b7 & 0xFF},
 	{0x116b8 & 0xFF, 0x116b8 & 0xFF},
 	{0x116c0 & 0xFF, 0x116c9 & 0xFF},
+	{0x116d0 & 0xFF, 0x116e3 & 0xFF},
 	{0x1171d & 0xFF, 0x1172b & 0xFF},
 	{0x11730 & 0xFF, 0x11739 & 0xFF},
 	{0x11800 & 0xFF, 0x1182b & 0xFF},
@@ -910,6 +929,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a8a & 0xFF, 0x11a99 & 0xFF},
 	{0x11a9d & 0xFF, 0x11a9d & 0xFF},
 	{0x11ab0 & 0xFF, 0x11af8 & 0xFF},
+	{0x11bc0 & 0xFF, 0x11be0 & 0xFF},
+	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
 	{0x11c0a & 0xFF, 0x11c2e & 0xFF},
 	{0x11c2f & 0xFF, 0x11c36 & 0xFF},
@@ -947,6 +968,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11f34 & 0xFF, 0x11f3a & 0xFF},
 	{0x11f3e & 0xFF, 0x11f42 & 0xFF},
 	{0x11f50 & 0xFF, 0x11f59 & 0xFF},
+	{0x11f5a & 0xFF, 0x11f5a & 0xFF},
 	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
 	{0x12000 & 0xFF, 0x120ff & 0xFF},
 	{0x12100 & 0xFF, 0x121ff & 0xFF},
@@ -965,9 +987,28 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x13440 & 0xFF, 0x13440 & 0xFF},
 	{0x13441 & 0xFF, 0x13446 & 0xFF},
 	{0x13447 & 0xFF, 0x13455 & 0xFF},
+	{0x13460 & 0xFF, 0x134ff & 0xFF},
+	{0x13500 & 0xFF, 0x135ff & 0xFF},
+	{0x13600 & 0xFF, 0x136ff & 0xFF},
+	{0x13700 & 0xFF, 0x137ff & 0xFF},
+	{0x13800 & 0xFF, 0x138ff & 0xFF},
+	{0x13900 & 0xFF, 0x139ff & 0xFF},
+	{0x13a00 & 0xFF, 0x13aff & 0xFF},
+	{0x13b00 & 0xFF, 0x13bff & 0xFF},
+	{0x13c00 & 0xFF, 0x13cff & 0xFF},
+	{0x13d00 & 0xFF, 0x13dff & 0xFF},
+	{0x13e00 & 0xFF, 0x13eff & 0xFF},
+	{0x13f00 & 0xFF, 0x13fff & 0xFF},
+	{0x14000 & 0xFF, 0x140ff & 0xFF},
+	{0x14100 & 0xFF, 0x141ff & 0xFF},
+	{0x14200 & 0xFF, 0x142ff & 0xFF},
+	{0x14300 & 0xFF, 0x143fa & 0xFF},
 	{0x14400 & 0xFF, 0x144ff & 0xFF},
 	{0x14500 & 0xFF, 0x145ff & 0xFF},
 	{0x14600 & 0xFF, 0x14646 & 0xFF},
+	{0x16100 & 0xFF, 0x1611d & 0xFF},
+	{0x1611e & 0xFF, 0x1612f & 0xFF},
+	{0x16130 & 0xFF, 0x16139 & 0xFF},
 	{0x16800 & 0xFF, 0x168ff & 0xFF},
 	{0x16900 & 0xFF, 0x169ff & 0xFF},
 	{0x16a00 & 0xFF, 0x16a38 & 0xFF},
@@ -983,6 +1024,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16b50 & 0xFF, 0x16b59 & 0xFF},
 	{0x16b63 & 0xFF, 0x16b77 & 0xFF},
 	{0x16b7d & 0xFF, 0x16b8f & 0xFF},
+	{0x16d40 & 0xFF, 0x16d6c & 0xFF},
+	{0x16d70 & 0xFF, 0x16d79 & 0xFF},
 	{0x16e40 & 0xFF, 0x16e7f & 0xFF},
 	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
 	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
@@ -1007,6 +1050,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
 	{0x1bc9d & 0xFF, 0x1bc9e & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
+	{0x1ccf0 & 0xFF, 0x1ccf9 & 0xFF},
 	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
 	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
 	{0x1d165 & 0xFF, 0x1d169 & 0xFF},
@@ -1078,6 +1122,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e4d0 & 0xFF, 0x1e4eb & 0xFF},
 	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
 	{0x1e4f0 & 0xFF, 0x1e4f9 & 0xFF},
+	{0x1e5d0 & 0xFF, 0x1e5ed & 0xFF},
+	{0x1e5ee & 0xFF, 0x1e5ef & 0xFF},
+	{0x1e5f0 & 0xFF, 0x1e5f0 & 0xFF},
+	{0x1e5f1 & 0xFF, 0x1e5fa & 0xFF},
 	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
 	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
 	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
@@ -1791,9 +1839,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
-	UNICODE_WB_MidNum,
 	UNICODE_WB_MidLetter,
-	UNICODE_WB_MidNum,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ExtendNumLet,
 	UNICODE_WB_ExtendNumLet,
@@ -1877,6 +1923,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -1900,9 +1947,14 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1980,6 +2032,20 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
@@ -2003,6 +2069,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
@@ -2044,6 +2111,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -2080,6 +2149,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2105,6 +2175,25 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
@@ -2117,6 +2206,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -2140,6 +2231,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Format,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -2212,6 +2304,10 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2395,6 +2491,7 @@ static const size_t unicode_starting_indextab[]={
 	280,
 	281,
 	282,
+	283,
 	284,
 	285,
 	286,
@@ -2411,19 +2508,37 @@ static const size_t unicode_starting_indextab[]={
 	306,
 	307,
 	308,
+	309,
+	310,
+	311,
+	312,
+	313,
+	314,
+	315,
+	316,
+	317,
+	318,
+	319,
+	320,
+	321,
+	322,
+	323,
 	324,
 	325,
 	326,
+	353,
 	360,
 	361,
 	362,
 	363,
+	365,
 	366,
 	367,
 	431,
 	432,
 	433,
 	444,
+	460,
 	463,
 	465,
 	466,
@@ -2437,6 +2552,7 @@ static const size_t unicode_starting_indextab[]={
 	481,
 	482,
 	484,
+	485,
 	487,
 	488,
 	489,
@@ -2551,84 +2667,104 @@ static const char32_t unicode_starting_pagetab[]={
 	653,
 	654,
 	658,
-	672,
-	689,
+	670,
+	687,
+	694,
 	696,
-	698,
-	701,
-	709,
-	713,
+	699,
+	707,
+	711,
+	722,
 	723,
-	724,
-	730,
-	740,
-	744,
-	758,
-	762,
-	765,
-	768,
-	772,
-	780,
-	796,
-	815,
-	829,
-	847,
-	858,
-	863,
-	871,
-	873,
-	878,
-	898,
-	911,
-	920,
-	938,
-	940,
-	949,
-	950,
-	951,
-	952,
-	953,
-	955,
-	956,
-	957,
-	958,
+	729,
+	739,
+	743,
+	757,
+	761,
+	764,
+	771,
+	776,
+	784,
+	800,
+	819,
+	833,
+	865,
+	876,
+	881,
+	890,
+	892,
+	897,
+	917,
+	930,
+	932,
+	941,
 	959,
-	960,
 	961,
-	966,
-	967,
-	968,
-	969,
-	970,
 	971,
+	972,
+	973,
+	974,
+	975,
+	977,
 	978,
-	984,
-	985,
+	979,
+	980,
+	981,
+	982,
+	983,
+	989,
+	990,
+	991,
+	992,
+	993,
+	994,
 	995,
+	996,
+	997,
 	998,
 	999,
+	1000,
+	1001,
 	1002,
-	1008,
+	1003,
+	1004,
+	1005,
+	1006,
+	1007,
 	1010,
-	1016,
-	1017,
+	1011,
+	1012,
+	1019,
+	1025,
 	1027,
-	1037,
+	1028,
+	1038,
+	1041,
 	1042,
+	1045,
 	1051,
-	1057,
-	1059,
-	1066,
+	1052,
+	1054,
+	1060,
+	1061,
 	1071,
-	1076,
-	1079,
-	1083,
-	1085,
-	1089,
-	1122,
-	1126,
+	1081,
+	1086,
+	1095,
+	1101,
+	1103,
+	1110,
+	1115,
+	1120,
+	1123,
 	1127,
-	1128,
-	1130
+	1131,
+	1133,
+	1137,
+	1170,
+	1174,
+	1175,
+	1176,
+	1178
 };
 
